Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(41)

Unified Diff: chrome/browser/ssl/chrome_security_state_model_client.cc

Issue 2345053006: Remove IsSynchronous API from NavigationHandle. (Closed)
Patch Set: Addressed review comments. Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ssl/chrome_security_state_model_client.cc
diff --git a/chrome/browser/ssl/chrome_security_state_model_client.cc b/chrome/browser/ssl/chrome_security_state_model_client.cc
index 5b7097e4b4e89c8b0c8ad8d31ffc030aa4cd8fbe..8b79a30a37e4882e7671207124c708667760adc8 100644
--- a/chrome/browser/ssl/chrome_security_state_model_client.cc
+++ b/chrome/browser/ssl/chrome_security_state_model_client.cc
@@ -362,11 +362,9 @@ void ChromeSecurityStateModelClient::VisibleSSLStateChanged() {
void ChromeSecurityStateModelClient::DidFinishNavigation(
content::NavigationHandle* navigation_handle) {
- if (navigation_handle->IsInMainFrame() &&
- !navigation_handle->IsSynchronousNavigation()) {
+ if (navigation_handle->IsInMainFrame() && !navigation_handle->IsSamePage()) {
// Only reset the console message flag for main-frame navigations,
// and not for synchronous navigations like reference fragments and
// pushState.
logged_http_warning_on_current_navigation_ = false;
}
}
@@ -362,11 +362,9 @@ void ChromeSecurityStateModelClient::VisibleSSLStateChanged() {
// Only reset the console message flag for main-frame navigations,
- // and not for synchronous navigations like reference fragments and
- // pushState.
+ // and not for same-page navigations like reference fragments and pushState.
logged_http_warning_on_current_navigation_ = false;
}

Powered by Google App Engine
This is Rietveld 408576698